///////////////////////////////////////////////////////////
//
//  File: SFR300.h
//
//  Suprema UniFinger Engine SFR300 ver.2 SDK
//  Header File
//
//  Copyright (C) 2006, Suprema Inc.
//
///////////////////////////////////////////////////////////

#ifndef SFR300_H_INCLUDED
#define SFR300_H_INCLUDED

#ifdef SFA_EXPORTS
#define SFA_API __declspec(dllexport)
#else
#define SFA_API
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define SF_TEMPLATESIZE 384

#define SF_VERIFYFAIL    0
#define SF_MATCHFAIL     0
#define SF_MATCHTIMEOUT  128
#define SF_MATCHABORT    129

#define SF_SUCCESS       1
#define SF_NOTGOODIMAGE  2

#define SF_CORETOCENTER  4
#define SF_CORETOLEFT    8
#define SF_CORETORIGHT   16
#define SF_CORETOTOP     32
#define SF_CORETOBOTTOM  64

#define SF_NORMAL_MODE		0
#define SF_FAST_MODE		1
#define SF_INVALID_MODE		-1

enum {
	SFR_NONE,
	SFR_200,
	SFR_300,
	SFR_300_V2
};

SFA_API int __stdcall SF_Initialize();
SFA_API void __stdcall SF_Uninitialize();
SFA_API int __stdcall SF_SelectReader(int ReaderType);

// for SFR200
SFA_API int __stdcall SF_GetDeviceNumber();
SFA_API int __stdcall SF_GetDevice();
SFA_API int __stdcall SF_SetDevice( int Device );
SFA_API int __stdcall SF_GetSerial( unsigned char* Serial );
// end for SFR200

SFA_API int __stdcall SF_GetTimeout();
SFA_API int __stdcall SF_SetTimeout( int Timeout );
SFA_API int __stdcall SF_GetBrightness();
SFA_API int __stdcall SF_SetBrightness( int Brightness );
SFA_API int __stdcall SF_GetSensitivity();
SFA_API int __stdcall SF_SetSensitivity( int Sensitivity );

SFA_API int __stdcall SF_IsSensorOn();
SFA_API int __stdcall SF_IsFingerOn();
SFA_API int __stdcall SF_Capture();
SFA_API void __stdcall SF_AbortCapturing();

SFA_API int __stdcall SF_GetImageWidth();
SFA_API int __stdcall SF_GetImageHeight();
SFA_API unsigned char* __stdcall SF_GetImageBuffer();

SFA_API void __stdcall SF_Clear();
#ifdef _WINDOWS
SFA_API void __stdcall SF_Draw( HWND hWnd, int l, int t, int r, int b, int bCore );
#endif

SFA_API int __stdcall SF_Enroll( unsigned char* Template, int* TemplateSize, int bCoreDetect );
SFA_API int __stdcall SF_EnrollWithVerify( unsigned char* Template, int* TemplateSize, int bCoreDetect );
SFA_API int __stdcall SF_Verify( unsigned char* Template, int SecurityLevel, int bCoreDetect );
SFA_API int __stdcall SF_Identify( unsigned char** Template, int Count, int* Match, int SecurityLevel, int bCoreDetect, int Timeout );
SFA_API int __stdcall SF_IdentifyMT( unsigned char** Template, int Count, int* Match, int SecurityLevel, int bCoreDetect, int Timeout );

SFA_API int __stdcall SF_GetEnrollQuality();
SFA_API void __stdcall SF_AbortMatching();
SFA_API void __stdcall SF_RotateTemplate( unsigned char* Template );

SFA_API int __stdcall SF_SetFastMode( int Mode );
#ifdef __cplusplus
}
#endif

#endif // SFR300_H_INCLUDED
